==> endoreg_db-0.3.6.tar.gz: endoreg_db-0.3.6/endoreg_db/data/__init__.py <==
from pathlib import Path

DATA_DIR = Path(__file__).parent

INFORMATION_DATA_DIR = DATA_DIR / "information_source"
UNIT_DATA_DIR = DATA_DIR / "unit"
CENTER_DATA_DIR = DATA_DIR / "center"
EXAMINATION_DATA_DIR = DATA_DIR / "examination"
LABEL_DATA_DIR = DATA_DIR / "label"
MODEL_TYPE_DATA_DIR = DATA_DIR / "model_type"
ENDOSCOPY_PROCESSOR_DATA_DIR = DATA_DIR / "endoscopy_processor"
ENDOSCOPE_TYPE_DATA_DIR = DATA_DIR / "endoscope_type"
ACTIVE_MODEL_DATA_DIR = DATA_DIR / "active_model"
PROFESSION_DATA_DIR = DATA_DIR / "profession"
PDF_TYPE_DATA_DIR = DATA_DIR / "pdf_type"
REPORT_READER_FLAG_DATA_DIR = DATA_DIR / "report_reader_flag"
EVENT_DATA_DIR = DATA_DIR / "event"
GENDER_DATA_DIR = DATA_DIR / "gender"

# Green Endoscopy Dashboard Stuffs
CENTER_RESOURCE_DATA_DIR = DATA_DIR / "center_resource"
CENTER_WASTE_DATA_DIR = DATA_DIR / "center_waste"
EMISSION_FACTOR_DATA_DIR = DATA_DIR / "emission_factor"
MATERIAL_DATA_DIR = DATA_DIR / "material"
PRODUCT_DATA_DIR = DATA_DIR / "product"
PRODUCT_GROUP_DATA_DIR = DATA_DIR / "product_group"
PRODUCT_MATERIAL_DATA_DIR = DATA_DIR / "product_material"
PRODUCT_WEIGHT_DATA_DIR = DATA_DIR / "product_weight"
REFERENCE_PRODUCT_DATA_DIR = DATA_DIR / "reference_product"
RESOURCE_DATA_DIR = DATA_DIR / "resource"
WASTE_DATA_DIR = DATA_DIR / "waste"
TRANSPORT_ROUTE_DATA_DIR = DATA_DIR / "transport_route"
DISEASE_CLASSIFICATION_DATA_DIR = DATA_DIR / "disease_classification"
DISEASE_CLASSIFICATION_CHOICE_DATA_DIR = DATA_DIR / "disease_classification_choice"
DISEASE_DATA_DIR = DATA_DIR / "disease"
MEDICATION_DATA_DIR = DATA_DIR / "medication"
MEDICATION_INDICATION_DATA_DIR = DATA_DIR / "medication_indication"
MEDICATION_INDICATION_TYPE_DATA_DIR = DATA_DIR / "medication_indication_type"

DISTRIBUTION_BASE_DIR = DATA_DIR / "distribution"
DISTRIBUTION_SINGLE_CATEGORICAL_DATA_DIR = DISTRIBUTION_BASE_DIR / "single_categorical"
DISTRIBUTION_NUMERIC_DATA_DIR = DISTRIBUTION_BASE_DIR / "numeric"
DISTRIBUTION_MULTIPLE_CATEGORICAL_DATA_DIR = DISTRIBUTION_BASE_DIR / "multiple_categorical"
DISTRIBUTION_DATE_DATA_DIR = DISTRIBUTION_BASE_DIR / "date"

# G-Play Stuffs
CASE_TEMPLATE_BASE_DIR = DATA_DIR / "case_template"
CASE_TEMPLATE_DATA_DIR = CASE_TEMPLATE_BASE_DIR / "template"
CASE_TEMPLATE_TYPE_DATA_DIR = CASE_TEMPLATE_BASE_DIR / "template_type"
CASE_TEMPLATE_RULE_DATA_DIR = CASE_TEMPLATE_BASE_DIR / "rule"
CASE_TEMPLATE_RULE_TYPE_DATA_DIR = CASE_TEMPLATE_BASE_DIR / "rule_type"
CASE_TEMPLATE_RULE_VALUE_DATA_DIR = CASE_TEMPLATE_BASE_DIR / "rule_value"
CASE_TEMPLATE_RULE_VALUE_TYPE_DATA_DIR = CASE_TEMPLATE_BASE_DIR / "rule_value_type"


# To Do
LAB_VALUE_DATA_DIR = DATA_DIR / "lab_value"
PATIENT_LAB_SAMPLE_TYPE_DATA_DIR = DATA_DIR / "patient_lab_sample_type"
MEDICATION_SCHEDULE_DATA_DIR = DATA_DIR / "medication_schedule"
MEDICATION_INTAKE_TIME_DATA_DIR = DATA_DIR / "medication_intake_time"


RULE_TYPE_DATA_DIR = DATA_DIR / "rule_type"
RULE_ATTRIBUTE_DTYPE_DATA_DIR = DATA_DIR / "rule_attribute_dtype"
RULESET_DATA_DIR = DATA_DIR / "ruleset"

==> endoreg_db-0.4.3.tar.gz: endoreg_db-0.4.3/endoreg_db/data/__init__.py <==
from pathlib import Path

DATA_DIR = Path(__file__).parent

INFORMATION_DATA_DIR = DATA_DIR / "information_source"
UNIT_DATA_DIR = DATA_DIR / "unit"
CENTER_DATA_DIR = DATA_DIR / "center"
EXAMINATION_DATA_DIR = DATA_DIR / "examination"
LABEL_DATA_DIR = DATA_DIR / "label"
MODEL_TYPE_DATA_DIR = DATA_DIR / "model_type"
ENDOSCOPY_PROCESSOR_DATA_DIR = DATA_DIR / "endoscopy_processor"
ENDOSCOPE_TYPE_DATA_DIR = DATA_DIR / "endoscope_type"
ACTIVE_MODEL_DATA_DIR = DATA_DIR / "active_model"
PROFESSION_DATA_DIR = DATA_DIR / "profession"
PDF_TYPE_DATA_DIR = DATA_DIR / "pdf_type"
REPORT_READER_FLAG_DATA_DIR = DATA_DIR / "report_reader_flag"
EVENT_DATA_DIR = DATA_DIR / "event"
GENDER_DATA_DIR = DATA_DIR / "gender"

# Green Endoscopy Dashboard Stuffs
CENTER_RESOURCE_DATA_DIR = DATA_DIR / "center_resource"
CENTER_WASTE_DATA_DIR = DATA_DIR / "center_waste"
EMISSION_FACTOR_DATA_DIR = DATA_DIR / "emission_factor"
MATERIAL_DATA_DIR = DATA_DIR / "material"
PRODUCT_DATA_DIR = DATA_DIR / "product"
PRODUCT_GROUP_DATA_DIR = DATA_DIR / "product_group"
PRODUCT_MATERIAL_DATA_DIR = DATA_DIR / "product_material"
PRODUCT_WEIGHT_DATA_DIR = DATA_DIR / "product_weight"
REFERENCE_PRODUCT_DATA_DIR = DATA_DIR / "reference_product"
RESOURCE_DATA_DIR = DATA_DIR / "resource"
WASTE_DATA_DIR = DATA_DIR / "waste"
TRANSPORT_ROUTE_DATA_DIR = DATA_DIR / "transport_route"
DISEASE_CLASSIFICATION_DATA_DIR = DATA_DIR / "disease_classification"
DISEASE_CLASSIFICATION_CHOICE_DATA_DIR = DATA_DIR / "disease_classification_choice"
DISEASE_DATA_DIR = DATA_DIR / "disease"
MEDICATION_DATA_DIR = DATA_DIR / "medication"
MEDICATION_INDICATION_DATA_DIR = DATA_DIR / "medication_indication"
MEDICATION_INDICATION_TYPE_DATA_DIR = DATA_DIR / "medication_indication_type"

DISTRIBUTION_BASE_DIR = DATA_DIR / "distribution"
DISTRIBUTION_SINGLE_CATEGORICAL_DATA_DIR = DISTRIBUTION_BASE_DIR / "single_categorical"
DISTRIBUTION_NUMERIC_DATA_DIR = DISTRIBUTION_BASE_DIR / "numeric"
DISTRIBUTION_MULTIPLE_CATEGORICAL_DATA_DIR = DISTRIBUTION_BASE_DIR / "multiple_categorical"
DISTRIBUTION_DATE_DATA_DIR = DISTRIBUTION_BASE_DIR / "date"

# G-Play Stuffs
CASE_TEMPLATE_BASE_DIR = DATA_DIR / "case_template"
CASE_TEMPLATE_DATA_DIR = CASE_TEMPLATE_BASE_DIR / "template"
CASE_TEMPLATE_TYPE_DATA_DIR = CASE_TEMPLATE_BASE_DIR / "template_type"
CASE_TEMPLATE_RULE_DATA_DIR = CASE_TEMPLATE_BASE_DIR / "rule"
CASE_TEMPLATE_RULE_TYPE_DATA_DIR = CASE_TEMPLATE_BASE_DIR / "rule_type"
CASE_TEMPLATE_RULE_VALUE_DATA_DIR = CASE_TEMPLATE_BASE_DIR / "rule_value"
CASE_TEMPLATE_RULE_VALUE_TYPE_DATA_DIR = CASE_TEMPLATE_BASE_DIR / "rule_value_type"

# NETWORK
NETWORK_DEVICE_DATA_DIR = DATA_DIR / "network_device"
NETWORK_DEVICE_TYPE_DATA_DIR = DATA_DIR / "network_device_type"
AGL_SERVICE_DATA_DIR = DATA_DIR / "agl_service"

# LOGS
LOG_TYPE_DATA_DIR = DATA_DIR / "log_type"

# To Do
LAB_VALUE_DATA_DIR = DATA_DIR / "lab_value"
PATIENT_LAB_SAMPLE_TYPE_DATA_DIR = DATA_DIR / "patient_lab_sample_type"
MEDICATION_SCHEDULE_DATA_DIR = DATA_DIR / "medication_schedule"
MEDICATION_INTAKE_TIME_DATA_DIR = DATA_DIR / "medication_intake_time"


RULE_TYPE_DATA_DIR = DATA_DIR / "rule_type"
RULE_ATTRIBUTE_DTYPE_DATA_DIR = DATA_DIR / "rule_attribute_dtype"
RULESET_DATA_DIR = DATA_DIR / "ruleset"
